<?php

namespace Drupal\Tests\msf\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * The Multistep Node module load tests.
 *
 * @group msf
 */
class ModuleLoadTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stable9';

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'node',
    'block',
    'field_group',
    'msf',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->drupalPlaceBlock('page_title_block');
  }

  /**
   * Test the homepage after enabling the module Multistep Node.
   */
  public function testHomepage() {
    // Check the homepage.
    $this->drupalGet('<front>');
    $this->assertSession()->statusCodeEquals(200);

    // Minimal homepage title check.
    $this->assertSession()->pageTextContains('Log in');
  }

  /**
   * Test the Multistep Node module unistall.
   */
  public function testModuleUninstall() {
    // Create a new admin user.
    $admin_user = $this->drupalCreateUser([
      'access administration pages',
      'administer site configuration',
      'administer modules',
    ]);
    // Uninstall the module.
    $this->drupalLogin($admin_user);
    $this->drupalGet('/admin/modules/uninstall');
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->pageTextContains('Multistep Node');
    $this->submitForm(['uninstall[msf]' => TRUE], 'Uninstall');
    $this->submitForm([], 'Uninstall');
    $this->assertSession()->pageTextContains('The selected modules have been uninstalled.');
    $this->assertSession()->pageTextNotContains('Multistep Node');

    // Visit the frontpage.
    $this->drupalGet('<front>');
    $this->assertSession()->statusCodeEquals(200);
  }

  /**
   * Test the Multistep Node module reinstalling after being uninstalled.
   */
  public function testReinstallAfterUninstall() {
    // Create a new admin user.
    $admin_user = $this->drupalCreateUser([
      'access administration pages',
      'administer site configuration',
      'administer modules',
    ]);
    // Uninstall the module.
    $this->drupalLogin($admin_user);

    $page = $this->getSession()->getPage();
    $assert_session = $this->assertSession();

    // Uninstall the Multistep Node module.
    $this->container->get('module_installer')->uninstall(['msf'], FALSE);

    // Install the Multistep Node module.
    $this->drupalGet('/admin/modules');
    $page->checkField('modules[msf][enable]');
    $page->pressButton('Install');
    $assert_session->pageTextNotContains('Unable to install Multistep Node');
    $assert_session->pageTextContains('Module Multistep Node has been enabled');
  }

}
